@@ -81,7 +81,7 @@ public:
 
     template<typename... Args>
     static std::shared_ptr<Responder> make(
-      Args&& ... args)
+      Args&&... args)
     {
       auto responder = std::make_shared<Responder>(std::forward<Args>(args)...);
       rclcpp::Node& node = responder->impl->node;
@@ -100,6 +100,7 @@ public:
     }
 
     void submit(
+      rmf_traffic::PlanId plan_id,
       std::vector<rmf_traffic::Route> itinerary,
       std::function<UpdateVersion()> approval_callback) const final
     {
@@ -107,7 +108,7 @@ public:
       if (table->defunct())
         return;
 
-      if (table->submit(itinerary, table_version+1))
+      if (table->submit(plan_id, itinerary, table_version+1))
       {
         impl->approvals[conflict_version][table] = {
           table->sequence(),
@@ -416,7 +417,7 @@ public:
         + std::to_string(msg.conflict_version) + "], table ["
         + table_to_string(msg.table) + " ]";
 
-      RCLCPP_WARN(node.get_logger(), error.c_str());
+      RCLCPP_WARN(node.get_logger(), "%s", error.c_str());
 
       return;
     }
@@ -572,7 +573,7 @@ public:
           p.version);
       error += " " + std::to_string(msg.for_participant) + " ]";
 
-      RCLCPP_WARN(node.get_logger(), error.c_str());
+      RCLCPP_WARN(node.get_logger(), "%s", error.c_str());
       room.cached_proposals.push_back(msg);
       return;
     }
@@ -580,8 +581,8 @@ public:
     // We'll keep track of these negotiations whether or not we're participating
     // in them, because one of our negotiators might get added to it in the
     // future
-    const bool updated =
-      received_table->submit(convert(msg.itinerary), msg.proposal_version);
+    const bool updated = received_table->submit(
+      msg.plan_id, convert(msg.itinerary), msg.proposal_version);
 
     if (!updated)
       return;
@@ -637,7 +638,7 @@ public:
           p.version);
       error += " ]";
 
-      RCLCPP_WARN(node.get_logger(), error.c_str());
+      RCLCPP_WARN(node.get_logger(), "%s", error.c_str());
 
       room.cached_rejections.push_back(msg);
       return;
@@ -933,14 +934,13 @@ public:
     const Version conflict_version,
     const Negotiation::Table& table)
   {
-    Proposal msg;
-    msg.conflict_version = conflict_version;
-    msg.proposal_version = table.version();
-
-    assert(table.submission());
-    msg.itinerary = convert(*table.submission());
-    msg.for_participant = table.participant();
-    msg.to_accommodate = convert(table.sequence());
+    Proposal msg = rmf_traffic_msgs::build<Proposal>()
+      .conflict_version(conflict_version)
+      .proposal_version(table.version())
+      .for_participant(table.participant())
+      .to_accommodate(convert(table.sequence()))
+      .plan_id(table.proposal().back().plan)
+      .itinerary(convert(*table.submission()));
 
     // Make sure to pop the back off of msg.to_accommodate, because we don't
     // want to include this table's final sequence key. That final key is
